@@ -5,15 +5,87 @@ set -o errexit
 
 ###
 # Baldur's Gate 3
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250104.1
+script_version=20250415.1
 
 PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
 GAME_ID='baldurs-gate-3'
 GAME_NAME='Baldurʼs Gate Ⅲ'
 
+ARCHIVE_BASE_PATCH7_1_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035).exe'
+ARCHIVE_BASE_PATCH7_1_MD5='e49b2196b60ef76d39ece0c3b45e2382'
+ARCHIVE_BASE_PATCH7_1_TYPE='innosetup'
+ARCHIVE_BASE_PATCH7_1_PART1_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-1.bin'
+ARCHIVE_BASE_PATCH7_1_PART1_MD5='ccc70b5170c78451af59378cd07f00c4'
+ARCHIVE_BASE_PATCH7_1_PART2_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-2.bin'
+ARCHIVE_BASE_PATCH7_1_PART2_MD5='8d63d6e0527ed25093764220cd6697d3'
+ARCHIVE_BASE_PATCH7_1_PART3_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-3.bin'
+ARCHIVE_BASE_PATCH7_1_PART3_MD5='dc4a7756f4043b38313a02d77a83fb30'
+ARCHIVE_BASE_PATCH7_1_PART4_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-4.bin'
+ARCHIVE_BASE_PATCH7_1_PART4_MD5='e7da48782fd10869b7c673bf6c440323'
+ARCHIVE_BASE_PATCH7_1_PART5_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-5.bin'
+ARCHIVE_BASE_PATCH7_1_PART5_MD5='4186fbc6f85228737c1e75e64e5979ea'
+ARCHIVE_BASE_PATCH7_1_PART6_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-6.bin'
+ARCHIVE_BASE_PATCH7_1_PART6_MD5='a95f13f119e8bfad2ba8e691f37a7b45'
+ARCHIVE_BASE_PATCH7_1_PART7_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-7.bin'
+ARCHIVE_BASE_PATCH7_1_PART7_MD5='dcdd32dac6148e95784d0967e76631ed'
+ARCHIVE_BASE_PATCH7_1_PART8_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-8.bin'
+ARCHIVE_BASE_PATCH7_1_PART8_MD5='94632f860d3bf729951cba45a2ef1b49'
+ARCHIVE_BASE_PATCH7_1_PART9_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-9.bin'
+ARCHIVE_BASE_PATCH7_1_PART9_MD5='50f09f05df55f31a51e4dbe3be2c98ca'
+ARCHIVE_BASE_PATCH7_1_PART10_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-10.bin'
+ARCHIVE_BASE_PATCH7_1_PART10_MD5='688a0e7731f738550cbfc411e446df59'
+ARCHIVE_BASE_PATCH7_1_PART11_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-11.bin'
+ARCHIVE_BASE_PATCH7_1_PART11_MD5='6462b7d0535b861cdd12910710283f79'
+ARCHIVE_BASE_PATCH7_1_PART12_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-12.bin'
+ARCHIVE_BASE_PATCH7_1_PART12_MD5='f3b88af77ca87095d0fbbbe35d4e149b'
+ARCHIVE_BASE_PATCH7_1_PART13_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-13.bin'
+ARCHIVE_BASE_PATCH7_1_PART13_MD5='83eb0050d03a53a11adcf489657099fc'
+ARCHIVE_BASE_PATCH7_1_PART14_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-14.bin'
+ARCHIVE_BASE_PATCH7_1_PART14_MD5='002cfe500a6b7d3a26676576505e33f5'
+ARCHIVE_BASE_PATCH7_1_PART15_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-15.bin'
+ARCHIVE_BASE_PATCH7_1_PART15_MD5='bb72f89ba73b9d8d9db50eccf6d3f37a'
+ARCHIVE_BASE_PATCH7_1_PART16_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-16.bin'
+ARCHIVE_BASE_PATCH7_1_PART16_MD5='f4812aa946048954fd3d906bdcf1ec63'
+ARCHIVE_BASE_PATCH7_1_PART17_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-17.bin'
+ARCHIVE_BASE_PATCH7_1_PART17_MD5='a07e72be29ddec457388ec75eb97a0ce'
+ARCHIVE_BASE_PATCH7_1_PART18_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-18.bin'
+ARCHIVE_BASE_PATCH7_1_PART18_MD5='80ff7ccb2ceb4467af66f1c24d6afc7a'
+ARCHIVE_BASE_PATCH7_1_PART19_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-19.bin'
+ARCHIVE_BASE_PATCH7_1_PART19_MD5='7715912bf7256332eb1ac29567fb43ff'
+ARCHIVE_BASE_PATCH7_1_PART20_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-20.bin'
+ARCHIVE_BASE_PATCH7_1_PART20_MD5='811ec163e7a378f3c745e4995c6d696e'
+ARCHIVE_BASE_PATCH7_1_PART21_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-21.bin'
+ARCHIVE_BASE_PATCH7_1_PART21_MD5='e8bb834f904b0c87f8122b21a2ab3c52'
+ARCHIVE_BASE_PATCH7_1_PART22_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-22.bin'
+ARCHIVE_BASE_PATCH7_1_PART22_MD5='0ed518e8074550ad482478a299854c7b'
+ARCHIVE_BASE_PATCH7_1_PART23_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-23.bin'
+ARCHIVE_BASE_PATCH7_1_PART23_MD5='b76e7aed77fe5a135672a39c15670226'
+ARCHIVE_BASE_PATCH7_1_PART24_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-24.bin'
+ARCHIVE_BASE_PATCH7_1_PART24_MD5='504f1a93c47448c708bbd98949b1da94'
+ARCHIVE_BASE_PATCH7_1_PART25_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-25.bin'
+ARCHIVE_BASE_PATCH7_1_PART25_MD5='a54f1c6dda05b074d12d85f927483352'
+ARCHIVE_BASE_PATCH7_1_PART26_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-26.bin'
+ARCHIVE_BASE_PATCH7_1_PART26_MD5='db09910df98ac5d48da3da401a4d48c0'
+ARCHIVE_BASE_PATCH7_1_PART27_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-27.bin'
+ARCHIVE_BASE_PATCH7_1_PART27_MD5='ecb67780a96b9813153cf9f242e06e06'
+ARCHIVE_BASE_PATCH7_1_PART28_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-28.bin'
+ARCHIVE_BASE_PATCH7_1_PART28_MD5='3985434483da3658f0d6af669ea0d498'
+ARCHIVE_BASE_PATCH7_1_PART29_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-29.bin'
+ARCHIVE_BASE_PATCH7_1_PART29_MD5='77e6fb2852c03ed51793f30ed8378d4b'
+ARCHIVE_BASE_PATCH7_1_PART30_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-30.bin'
+ARCHIVE_BASE_PATCH7_1_PART30_MD5='6b492781abf4ce82ada772247cdb7418'
+ARCHIVE_BASE_PATCH7_1_PART31_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-31.bin'
+ARCHIVE_BASE_PATCH7_1_PART31_MD5='ed85272a3d4d0c8546a79d5f84c7e87b'
+ARCHIVE_BASE_PATCH7_1_PART32_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035)-32.bin'
+ARCHIVE_BASE_PATCH7_1_PART32_MD5='72b4ebad04dce811414037e87743eb63'
+ARCHIVE_BASE_PATCH7_1_SIZE='151202043'
+ARCHIVE_BASE_PATCH7_1_VERSION='4.1.1.6072089-gog77035'
+ARCHIVE_BASE_PATCH7_1_URL='https://www.gog.com/game/baldurs_gate_iii'
+
 ARCHIVE_BASE_PATCH7_0_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089_-_patch_patch7_hotfix3_(64bit)_(77035).exe'
 ARCHIVE_BASE_PATCH7_0_MD5='4731f40c3ba5a04baa46f83954a11dc8'
 ARCHIVE_BASE_PATCH7_0_TYPE='innosetup'
@@ -83,7 +155,6 @@ ARCHIVE_BASE_PATCH7_0_PART32_NAME='setup_baldurs_gate_3_release_-_v4.1.1.6072089
 ARCHIVE_BASE_PATCH7_0_PART32_MD5='4209e5bdcc87061a22236b28759eba18'
 ARCHIVE_BASE_PATCH7_0_SIZE='151199932'
 ARCHIVE_BASE_PATCH7_0_VERSION='4.1.1.6072089-gog77035'
-ARCHIVE_BASE_PATCH7_0_URL='https://www.gog.com/game/baldurs_gate_iii'
 
 ARCHIVE_BASE_PATCH6_1_NAME='setup_baldurs_gate_3_release_-_v4.1.1.5022896_-_patch_patch6_hotfix9__(64bit)_(72479).exe'
 ARCHIVE_BASE_PATCH6_1_MD5='a68f1a0edcf026a1095c20efe1fa6edc'
