@@ -9,9 +9,9 @@ set -o errexit
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250504.1
+script_version=20251015.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.32'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='ballisticng'
 GAME_NAME='BallisticNG'
@@ -19,11 +19,16 @@ GAME_NAME='BallisticNG'
 EXPANSION_ID_NEON='neon-nights'
 EXPANSION_NAME_NEON='Neon Nights'
 
+ARCHIVE_BASE_NEON_2_NAME='ballisticng_neon_nights_1_4_0_1b_81954.sh'
+ARCHIVE_BASE_NEON_2_MD5='5d2391186e508eda373e7caf24eba6f6'
+ARCHIVE_BASE_NEON_2_SIZE='100096'
+ARCHIVE_BASE_NEON_2_VERSION='1.4.0.1b-gog81954'
+ARCHIVE_BASE_NEON_2_URL='https://www.gog.com/game/ballisticng_neon_nights'
+
 ARCHIVE_BASE_NEON_1_NAME='ballisticng_neon_nights_1_4_0_1_81860.sh'
 ARCHIVE_BASE_NEON_1_MD5='10d999ef9faeded119f293c6ee8b6d7e'
 ARCHIVE_BASE_NEON_1_SIZE='100096'
 ARCHIVE_BASE_NEON_1_VERSION='1.4.0.1-gog81860'
-ARCHIVE_BASE_NEON_1_URL='https://www.gog.com/game/ballisticng_neon_nights'
 
 ARCHIVE_BASE_NEON_0_NAME='ballisticng_neon_nights_1_3_3_1_69502.sh'
 ARCHIVE_BASE_NEON_0_MD5='18897d4477a80a88afe3a05fa52cfee9'
@@ -39,7 +44,7 @@ PKG_PARENT_ID="$GAME_ID"
 PKG_MAIN_DEPENDENCIES_SIBLINGS='
 PKG_PARENT'
 
-# Load common functions
+# Load common functions.
 
 PLAYIT_LIB_PATHS="
 $PWD
@@ -65,24 +70,24 @@ fi
 # shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
-# Run the default initialization actions
+# Run default initialisation actions.
 
 initialization_default "$@"
 
-# Extract game data
+# Extract game data.
 
 archive_extraction_default
 
-# Include game data
+# Include game data.
 
 content_inclusion_default
 
-# Build packages
+# Build packages.
 
 packages_generation
 print_instructions
 
-# Clean up
+# Clean up.
 
 working_directory_cleanup
 
