@@ -6,11 +6,12 @@ set -o errexit
 
 ###
 # Beyond Good and Evil
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241021.1
+script_version=20250310.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.31'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='beyond-good-and-evil'
 GAME_NAME='Beyond Good and Evil'
@@ -46,6 +47,13 @@ sally.idx
 
 WINE_REGEDIT_PERSISTENT_KEYS='
 HKEY_CURRENT_USER\Software\Ubisoft\Beyond Good & Evil\settingsapplication.INI'
+## Silence a ShellCheck false positive
+## SC1003 (info): Want to escape a single quote? echo 'This is how it'\''s done'.
+# shellcheck disable=SC1003
+WINE_REGISTRY_INIT='
+[HKEY_LOCAL_MACHINE\Software\Ubisoft\Beyond Good & Evil]
+
+"Install path"="C:\\'"${GAME_ID}"'"'
 
 APP_MAIN_EXE='run.exe'
 APP_MAIN_ICON='bge.exe'
@@ -72,20 +80,6 @@ PKG_DATA'
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
 
-# Set install path in registry
-
-install_path="C:\\\\${GAME_ID}"
-registry_dump_install_file='registry-dumps/install-path.reg'
-registry_dump_install_content='Windows Registry Editor Version 5.00
-
-[HKEY_LOCAL_MACHINE\Software\Ubisoft\Beyond Good & Evil]
-"Install path"="'"${install_path}"'"'
-CONTENT_GAME_BIN_FILES="${CONTENT_GAME_BIN_FILES:-}
-$registry_dump_install_file"
-APP_REGEDIT="${APP_REGEDIT:-} $registry_dump_install_file"
-REQUIREMENTS_LIST="${REQUIREMENTS_LIST:-}
-iconv"
-
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -132,14 +126,6 @@ fi'
 # Extract game data
 
 archive_extraction_default
-(
-	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
-
-	## Set install path in registry.
-	mkdir --parents "$(dirname "$registry_dump_install_file")"
-	printf '%s' "$registry_dump_install_content" | \
-		iconv --from-code=UTF-8 --to-code=UTF-16 --output="$registry_dump_install_file"
-)
 
 # Include game data
 
