@@ -5,11 +5,12 @@ set -o errexit
 
 ###
 # Dark Reign 2
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241021.1
+script_version=20250312.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.31'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='dark-reign-2'
 GAME_NAME='Dark Reign 2'
@@ -46,7 +47,7 @@ dr2.exe
 dxcfg.exe
 anet.inf
 dxcfg.ini'
-## On first launch, register the game CD-key.
+## Register the game CD-key
 ## This file is generated later in this script.
 CONTENT_GAME0_BIN_FILES='
 cdkey'
@@ -78,15 +79,6 @@ WINE_WINETRICKS_VERBS='win98'
 APP_MAIN_EXE='dr2.exe'
 APP_MAIN_EXE_0='launcher.exe'
 APP_MAIN_ICON='dr2.exe'
-## On first launch, register the game CD-key.
-APP_MAIN_PRERUN='
-# On first launch, register the game CD-key
-if [ ! -e .cdkey-registered ]; then
-	cdkey=$(cat cdkey)
-	$(wine_command) reg add "HKLM\\Software\\WON\\CDKeys" /v "DarkReign2" /t REG_BINARY /d "$cdkey" /f
-	touch .cdkey-registered
-fi
-'
 
 PACKAGES_LIST='
 PKG_BIN
@@ -99,7 +91,7 @@ PKG_DATA'
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
 
-# On first launch, register the game CD-key
+# Register the game CD-key
 
 REQUIREMENTS_LIST="${REQUIREMENTS_LIST:-}
 base64
@@ -141,10 +133,10 @@ archive_extraction_default
 (
 	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
 
-	## On first launch, register the game CD-key.
-	## The source is a base64-encoded string, that must be converted to an hexadecimal representation.
+	# Register the game CD-key
+	# The source is a base64-encoded string, that must be converted to an hexadecimal representation.
 	sed --silent '71s/.*"valueData": "\(.*\)",/\1/p' goggame-1207658911.script | \
-		base64 --decode | \
+		base64 --decode |
 		xxd -plain \
 		> 'cdkey'
 )
@@ -156,6 +148,14 @@ content_inclusion_default
 
 # Write launchers
 
+## Register the game CD-key
+wineprefix_init_custom() {
+	cat <<- 'EOF'
+	cdkey=$(cat "${PATH_GAME_DATA}/cdkey")
+	$(wine_command) reg add "HKLM\\Software\\WON\\CDKeys" /v "DarkReign2" /t REG_BINARY /d "$cdkey" /f
+	EOF
+}
+
 launchers_generation 'PKG_BIN'
 
 # Build packages
