@@ -8,20 +8,24 @@ set -o errexit
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250721.1
+script_version=20260913.1
 
 PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='darkest-dungeon'
 GAME_NAME='Darkest Dungeon'
 
-## This build is the one provided by GOG since 2025-05-29,
-## but it is an old build from 2018.
+ARCHIVE_BASE_1_NAME='darkest_dungeon_26186c_83747.sh'
+ARCHIVE_BASE_1_MD5='d738675c70bf4e11a79745403583af9b'
+ARCHIVE_BASE_1_SIZE='2294105'
+ARCHIVE_BASE_1_VERSION='26186c-gog83747'
+ARCHIVE_BASE_1_URL='https://www.gog.com/game/darkest_dungeon'
+
+## This build is the one provided by GOG since 2025-05-29, but it is an old build from 2018.
 ARCHIVE_BASE_OLD_8_NAME='darkest_dungeon_24788_82473.sh'
 ARCHIVE_BASE_OLD_8_MD5='875d36d3beca80c350c8848dc0e421c0'
 ARCHIVE_BASE_OLD_8_SIZE='2269724'
 ARCHIVE_BASE_OLD_8_VERSION='24788-gog82473'
-ARCHIVE_BASE_OLD_8_URL='https://www.gog.com/game/darkest_dungeon'
 
 ## This build comes with a broken installer for The Crimson Court expansion.
 ARCHIVE_BASE_0_NAME='darkest_dungeon_26186_81633.sh'
@@ -192,12 +196,12 @@ libstdc++.so.6'
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
 
-# Fix icon background transparency
+# Fix icon background transparency.
 
-REQUIREMENTS_LIST="${REQUIREMENTS_LIST:-}
-convert"
+REQUIREMENTS_LIST='
+convert'
 
-# Load common functions
+# Load common functions.
 
 PLAYIT_LIB_PATHS="
 $PWD
@@ -223,31 +227,30 @@ fi
 # shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
-# Run the default initialization actions
+# Run default initialisation actions.
 
 initialization_default "$@"
 
-# Extract game data
+# Extract game data.
 
 archive_extraction_default
-(
-	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
+## Fix icon background transparency.
+icon_path=$(icon_path 'APP_MAIN_ICON')
+convert \
+	"${PLAYIT_WORKDIR}/gamedata/$(content_path_default)/${icon_path}" \
+	-transparent "#008080" \
+	-transparent "#006e6e" \
+	"${PLAYIT_WORKDIR}/gamedata/$(content_path_default)/${icon_path%.bmp}_fixed.bmp"
+mv \
+	"${PLAYIT_WORKDIR}/gamedata/$(content_path_default)/${icon_path%.bmp}_fixed.bmp" \
+	"${PLAYIT_WORKDIR}/gamedata/$(content_path_default)/${icon_path}"
 
-	# Fix icon background transparency
-	icon_path=$(icon_path 'APP_MAIN_ICON')
-	convert "$icon_path" \
-		-transparent "#008080" \
-		-transparent "#006e6e" \
-		"${icon_path%.bmp}_fixed.bmp"
-	mv "${icon_path%.bmp}_fixed.bmp" "$icon_path"
-)
-
-# Include game data
+# Include game data.
 
 content_inclusion_icons 'PKG_DATA'
 content_inclusion_default
 
-# Write launchers
+# Write launchers.
 
 ## These values rely on both package context and archive context.
 APP_MAIN_EXE_BIN64=$(context_value 'APP_MAIN_EXE_BIN64')
@@ -256,12 +259,12 @@ APP_MAIN_EXE_BIN32=$(context_value 'APP_MAIN_EXE_BIN32')
 launchers_generation 'PKG_BIN64'
 launchers_generation 'PKG_BIN32'
 
-# Build packages
+# Build packages.
 
 packages_generation
 print_instructions
 
-# Clean up
+# Clean up.
 
 working_directory_cleanup
 
