@@ -6,11 +6,12 @@ set -o errexit
 
 ###
 # Deus Ex
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241021.1
+script_version=20250603.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.31'
+PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
 GAME_ID='deus-ex'
 GAME_NAME='Deus Ex'
@@ -112,18 +113,13 @@ system/*.log'
 USER_PERSISTENT_DIRECTORIES='
 save'
 
-## TODO: Check if the virtual desktop prevents the game from messing with the desktop gamma value on X.org.
-WINE_VIRTUAL_DESKTOP='auto'
+## Without a WINE virtual desktop, the game fails to render anything but a black window.
+## (WINE 10.0)
+WINE_VIRTUAL_DESKTOP='1280x1024'
 ## Disable csmt, as it would cause performance issues with single CPU affinity.
 WINE_WINETRICKS_VERBS='csmt=off'
 
 APP_MAIN_EXE='system/deusex.exe'
-## Run the game binary from its parent directory.
-APP_MAIN_PRERUN='
-# Run the game binary from its parent directory
-cd "$(dirname "$APP_EXE")"
-APP_EXE=$(basename "$APP_EXE")
-'
 
 PACKAGES_LIST='
 PKG_BIN
@@ -198,13 +194,17 @@ content_inclusion_default
 
 # Write launchers
 
-## Set the CPU affinity to a single core, to work around a random crash on launch.
+## Run the game binary from its parent directory
+##
+## Set the CPU affinity to a single core, to work around a random crash on launch
 ## cf. https://www.gamingonlinux.com/2020/02/the-sad-case-of-unreal-engine-1-on-mesa-and-linux-in-2020/page=2#r174041
 game_exec_line() {
 	cat <<- 'EOF'
+	# Run the game binary from its parent directory
+	cd system
 	# Set the CPU affinity to a single core, to work around a random crash on launch
 	# cf. https://www.gamingonlinux.com/2020/02/the-sad-case-of-unreal-engine-1-on-mesa-and-linux-in-2020/page=2#r174041
-	taskset --cpu-list 0 $(wine_command) "$APP_EXE" "$@"
+	taskset --cpu-list 0 "$(wine_command)" deusex.exe "$@"
 	EOF
 }
 
