@@ -7,9 +7,10 @@ set -o errexit
 # Impression Games city builders:
 # - Zeus: Master of Olympus
 # - Emperor: Rise of the Middle Kingdom
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241226.1
+script_version=20250606.1
 
 PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
@@ -80,9 +81,6 @@ USER_PERSISTENT_FILES='
 WINE_DIRECT3D_RENDERER='wined3d/gdi'
 ## The game window fails to render anything unless the game runs in a WINE virtual desktop (WINE 9.0).
 WINE_VIRTUAL_DESKTOP='auto'
-## Disable CSMT to avoid degraded performances
-## TODO: Check if it still required with current WINE builds
-WINE_WINETRICKS_VERBS='csmt=off'
 
 APPLICATIONS_LIST='APP_MAIN'
 
