@@ -5,11 +5,12 @@ set -o errexit
 
 ###
 # Jade Empire
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241229.1
+script_version=20250312.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.32'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='jade-empire'
 GAME_NAME='Jade Empire'
@@ -183,16 +184,14 @@ content_inclusion_default
 
 # Write launchers
 
-## Automatically spawn game settings window on first launch
+## Automatically spawn game settings
 ## Using desktop_field_exec here ensures that we get a path already escaped if required.
-settings_cmd=$(desktop_field_exec 'APP_CONFIG')
-APP_MAIN_PRERUN="$(application_prerun 'APP_MAIN')"'
-# Automatically spawn game settings window on first launch
-settings_file="JadeEmpire.ini"
-if [ ! -e "$settings_file" ]; then
-	'"${settings_cmd}"'
-fi
-'
+wineprefix_init_custom() {
+	cat <<- EOF
+	# Automatically spawn game settings
+	$(desktop_field_exec 'APP_CONFIG')
+	EOF
+}
 
 launchers_generation 'PKG_BIN'
 
