@@ -6,11 +6,12 @@ set -o errexit
 
 ###
 # Mask of the Rose
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241141.1
+script_version=20250606.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.31'
+PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
 GAME_ID='mask-of-the-rose'
 GAME_NAME='Mask of the Rose'
@@ -64,9 +65,6 @@ ARCHIVE_BASE_DEMO_0_VERSION='0.1.94-gog56552'
 
 UNITY3D_NAME='Mask of the Rose'
 UNITY3D_NAME_DEMO='Mask of the Rose Demo'
-## TODO: Check if this library is actually required
-UNITY3D_PLUGINS='
-lib_burst_generated.so'
 
 CONTENT_PATH_DEFAULT='data/noarch/game'
 
@@ -123,6 +121,12 @@ initialization_default "$@"
 # Extract game data
 
 archive_extraction_default
+(
+	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
+
+	# Drop unused Unity3D plugins.
+	rm --force --recursive "$(unity3d_name)_Data/Plugins"
+)
 
 # Include game data
 
