@@ -6,11 +6,12 @@ set -o errexit
 
 ###
 # Monkey Island 4
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241021.1
+script_version=20250722.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.31'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='monkey-island-4'
 GAME_NAME='Monkey Island 4: Escape from Monkey Island'
@@ -68,10 +69,15 @@ CONTENT_DOC_L10N_FILES='
 ## WINE
 
 CONTENT_GAME_BIN_WINE_FILES='
-*.asi
-*.dll
-*.exe
-*.flt'
+mp3dec.asi
+binkw32.dll
+mss32.dll
+monkey.exe
+monkey4.exe
+syscheck.exe
+chorus.flt
+reverb3.flt
+sdelay.flt'
 CONTENT_GAME0_BIN_WINE_PATH='__support/save'
 CONTENT_GAME0_BIN_WINE_FILES='
 saves'
@@ -88,6 +94,13 @@ APP_SCUMMVM_ICON='monkey4.exe'
 USER_PERSISTENT_DIRECTORIES='
 saves'
 
+## Silence a ShellCheck false positive
+## SC1003 (info): Want to escape a single quote? echo 'This is how it'\''s done'.
+# shellcheck disable=SC1003
+WINE_REGISTRY_INIT='
+[HKEY_LOCAL_MACHINE\Software\LucasArts Entertainment Company LLC\Monkey4\Retail]
+
+"Install path"="C:\\'"${GAME_ID}"'"'
 WINE_VIRTUAL_DESKTOP='auto'
 
 APP_WINE_EXE='monkey4.exe'
@@ -141,20 +154,6 @@ PKG_BIN_WINE_DESCRIPTION_EN='English version'
 PKG_BIN_WINE_DESCRIPTION_FR='French version'
 PKG_BIN_WINE_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
 
-# WINE - Register install path
-
-install_path="C:\\\\${GAME_ID}"
-registry_dump_installpath_file='registry-dumps/install-path.reg'
-registry_dump_installpath_content='Windows Registry Editor Version 5.00
-
-[HKEY_LOCAL_MACHINE\Software\LucasArts Entertainment Company LLC\Monkey4\Retail]
-"Install path"="'"${install_path}"'"'
-CONTENT_GAME_BIN_WINE_FILES="${CONTENT_GAME_BIN_WINE_FILES:-}
-$registry_dump_installpath_file"
-APP_REGEDIT="${APP_REGEDIT:-} $registry_dump_installpath_file"
-REQUIREMENTS_LIST="${REQUIREMENTS_LIST:-}
-iconv"
-
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -203,22 +202,6 @@ esac
 # Extract game data
 
 archive_extraction_default
-(
-	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
-
-	## Delete unwanted files.
-	## TODO: Check if this can be dropped in favour of a more explicit list of files to include.
-	rm --force --recursive \
-		'__redist' \
-		'commonappdata' \
-		'install' \
-		'tmp'
-
-	## WINE - Register install path.
-	mkdir --parents "$(dirname "$registry_dump_installpath_file")"
-	printf '%s' "$registry_dump_installpath_content" | \
-		iconv --from-code=UTF-8 --to-code=UTF-16 --output="$registry_dump_installpath_file"
-)
 
 # Include game data
 
