@@ -5,11 +5,12 @@ set -o errexit
 
 ###
 # Pharaoh
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241226.4
+script_version=20250713.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.32'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='pharaoh'
 GAME_NAME='Pharaoh'
@@ -30,11 +31,41 @@ ARCHIVE_BASE_0_URL='https://www.gog.com/game/pharaoh_cleopatra'
 ## Akhenaten
 ## cf. https://github.com/dalerank/Akhenaten
 
+### release 1466 (0.2.5)
+### WARNING: This build crashes on launch with the following trace:
+###
+### #0  0x000055d27448a432 in sig_handler at /home/runner/work/Akhenaten/Akhenaten/src/core/log.cpp:77:49
+### #1  0x00007f4f3c3c0def at /lib/x86_64-linux-gnu/libc.so.6
+### #2  0x00007f4f3c41595c in __pthread_kill_implementation at ./nptl/pthread_kill.c:44:76
+### #3  0x00007f4f3c3c0cc1 in __GI_raise at ./signal/../sysdeps/posix/raise.c:26:13
+### #4  0x00007f4f3c3a94ab in __GI_abort at ./stdlib/abort.c:73:3
+### #5  0x00007f4f3c3aa290 in __libc_message_impl at ./libio/../sysdeps/posix/libc_fatal.c:134:3
+### #6  0x00007f4f3c49c994 in __GI___fortify_fail at ./debug/fortify_fail.c:24:3
+### #7  0x00007f4f3c49c39f in __GI___chk_fail at ./debug/chk_fail.c:28:3
+### #8  0x00007f4f3c49d9a3 in __realpath_chk at ./debug/realpath_chk.c:30:5
+### #9  (inlined)          in realpath at /usr/include/x86_64-linux-gnu/bits/stdlib.h:48:25
+###       46:   size_t __sz = __glibc_objsize (__resolved);
+###       47:
+###       48:   if (__sz == (size_t) -1)
+###       49:     return __realpath_alias (__name, __resolved);
+### #10 0x000055d274711185 in js_vm_get_absolute_path(bstring<256ul>) at /home/runner/work/Akhenaten/Akhenaten/src/js/js.cpp:280:21
+### #11 0x000055d2747114d7 in js_vm_load_file_and_exec(char const*) at /home/runner/work/Akhenaten/Akhenaten/src/js/js.cpp:71:40
+### #12 0x000055d2747118af in js_reset_vm_state() at /home/runner/work/Akhenaten/Akhenaten/src/js/js.cpp:248:38
+### #13 0x000055d274711a12 in js_vm_setup() at /home/runner/work/Akhenaten/Akhenaten/src/js/js.cpp:302:22
+### #14 0x000055d27446d0aa in setup at /home/runner/work/Akhenaten/Akhenaten/src/platform/akhenaten.cpp:408:16
+### #15 0x000055d27443a78f in main at /home/runner/work/Akhenaten/Akhenaten/src/platform/akhenaten.cpp:628:10
+### #16 0x00007f4f3c3aaca7 in __libc_start_call_main at ./csu/../sysdeps/nptl/libc_start_call_main.h:58:16
+### #17 0x00007f4f3c3aad64 in __libc_start_main_impl at ./csu/../csu/libc-start.c:360:3
+### #18 0x000055d27446c0b4 at (…)/akhenaten.linux
+ARCHIVE_OPTIONAL_AKHENATEN_4_NAME='akhenaten.linux'
+ARCHIVE_OPTIONAL_AKHENATEN_4_MD5='a7e38f4e0863065754817285e193752b'
+ARCHIVE_OPTIONAL_AKHENATEN_4_SIZE='126251'
+ARCHIVE_OPTIONAL_AKHENATEN_4_URL='https://dalerank.itch.io/akhenaten'
+
 ### release 1036
 ARCHIVE_OPTIONAL_AKHENATEN_3_NAME='akhenaten.linux'
 ARCHIVE_OPTIONAL_AKHENATEN_3_MD5='d35934a08420b82d55ed41405d5bea61'
 ARCHIVE_OPTIONAL_AKHENATEN_3_SIZE='87467'
-ARCHIVE_OPTIONAL_AKHENATEN_3_URL='https://dalerank.itch.io/akhenaten'
 
 ### release 784
 ARCHIVE_OPTIONAL_AKHENATEN_2_NAME='akhenaten.linux'
@@ -98,9 +129,6 @@ USER_PERSISTENT_FILES='
 WINE_DIRECT3D_RENDERER='wined3d/gdi'
 ## WINE - The game window fails to render anything unless the game runs in a WINE virtual desktop (WINE 9.0).
 WINE_VIRTUAL_DESKTOP='auto'
-## WINE - Disable CSMT to avoid degraded performances
-## TODO: Check if it is still required with current WINE builds
-WINE_WINETRICKS_VERBS='csmt=off'
 
 APP_MAIN_EXE_BIN_LINUX='akhenaten.linux'
 APP_MAIN_EXE_BIN_WINE='Pharaoh.exe'
@@ -172,6 +200,7 @@ fi
 
 archive_initialize_optional \
 	'ARCHIVE_AKHENATEN' \
+	'ARCHIVE_OPTIONAL_AKHENATEN_4' \
 	'ARCHIVE_OPTIONAL_AKHENATEN_3' \
 	'ARCHIVE_OPTIONAL_AKHENATEN_2' \
 	'ARCHIVE_OPTIONAL_AKHENATEN_1' \
