@@ -5,11 +5,12 @@ set -o errexit
 
 ###
 # Rayman
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250103.2
+script_version=20250722.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.32'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='rayman-1'
 GAME_NAME='Rayman'
@@ -39,7 +40,7 @@ rayman'
 CONTENT_DOC_DATA_FILES='
 manual.pdf'
 
-GAME_IMAGE='game.ins'
+DOSBOX_DISK_IMAGE_PATH='game.ins'
 
 USER_PERSISTENT_FILES='
 rayman/vignet.dat
@@ -111,9 +112,9 @@ archive_extraction_default
 (
 	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
 
-	## Force the name of the disk image table of contents
+	## Enforce consistent name for the disk image table of content.
 	if [ -e 'game.inst' ]; then
-		mv 'game.inst' "$GAME_IMAGE"
+		mv 'game.inst' "$(dosbox_disk_image_path)"
 	fi
 )
 
