@@ -6,11 +6,12 @@ set -o errexit
 
 ###
 # Renowned Explorers: International Society
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250104.1
+script_version=20250721.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.32'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='renowned-explorers'
 GAME_NAME='Renowned Explorers: International Society'
@@ -73,39 +74,41 @@ ARCHIVE_BASE_WINDOWS_0_SIZE='1114877'
 ARCHIVE_BASE_WINDOWS_0_VERSION='525-gog46550'
 ARCHIVE_BASE_WINDOWS_0_URL='https://www.gog.com/game/renowned_explorers'
 
+CONTENT_GAME_DATA_FILES='
+data
+soundbanks
+settings.ini
+*.bni'
+
 CONTENT_PATH_DEFAULT_LINUX='data/noarch/game'
-CONTENT_PATH_DEFAULT_WINDOWS='.'
 CONTENT_GAME_BIN64_FILES_LINUX='
 x86_64/abbeycore'
+CONTENT_GAME_BIN32_FILES_LINUX='
+x86/abbeycore'
+
+CONTENT_PATH_DEFAULT_WINDOWS='.'
 CONTENT_GAME_BIN64_FILES_WINDOWS='
 win64/amd_ags_x64.dll
 win64/d3d11.dll
 win64/d3dcompiler_47.dll
 win64/dxgi.dll
 win64/abbeycore_win32.exe'
-## TODO: Check if the Galaxy libraries are required
+## The Windows build fails to start if the GOG Galaxy librarie are not included.
 CONTENT_GAME0_BIN64_FILES_WINDOWS='
 win64/galaxy64.dll
 win64/galaxypeer64.dll
 win64/goggalaxyhooks.dll'
-CONTENT_GAME_BIN32_FILES_LINUX='
-x86/abbeycore'
 CONTENT_GAME_BIN32_FILES_WINDOWS='
 win32/amd_ags_x86.dll
 win32/d3d11.dll
 win32/d3dcompiler_47.dll
 win32/dxgi.dll
 win32/abbeycore_win32.exe'
-## TODO: Check if the Galaxy libraries are required
+## The Windows build fails to start if the GOG Galaxy librarie are not included.
 CONTENT_GAME0_BIN32_FILES_WINDOWS='
 win32/galaxy.dll
 win32/galaxypeer.dll
 win32/goggalaxyhooks.dll'
-CONTENT_GAME_DATA_FILES='
-data
-soundbanks
-settings.ini
-*.bni'
 
 ## The game renders only a black screen and the mouse cursor
 ## when using the default wined3d renderer (WINE 10.0).
@@ -139,20 +142,12 @@ PKG_DATA'
 PKG_BIN_ID="${GAME_ID}-bin"
 PKG_BIN_ID_LINUX="${PKG_BIN_ID}-linux"
 PKG_BIN_ID_WINDOWS="${PKG_BIN_ID}-windows"
-PKG_BIN64_ID_LINUX="$PKG_BIN_ID_LINUX"
-PKG_BIN64_ID_WINDOWS="$PKG_BIN_ID_WINDOWS"
-PKG_BIN32_ID_LINUX="$PKG_BIN_ID_LINUX"
-PKG_BIN32_ID_WINDOWS="$PKG_BIN_ID_WINDOWS"
 PKG_BIN_PROVIDES="
 $PKG_BIN_ID"
-PKG_BIN64_PROVIDES="$PKG_BIN_PROVIDES"
-PKG_BIN32_PROVIDES="$PKG_BIN_PROVIDES"
 PKG_BIN64_ARCH='64'
 PKG_BIN32_ARCH='32'
 PKG_BIN_DEPENDENCIES_SIBLINGS='
 PKG_DATA'
-PKG_BIN64_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
-PKG_BIN32_DEPENDENCIES_SIBLINGS="$PKG_BIN_DEPENDENCIES_SIBLINGS"
 PKG_BIN_DEPENDENCIES_LIBRARIES_LINUX='
 libc++abi.so.1
 libc++.so.1
@@ -167,13 +162,9 @@ libSDL2-2.0.so.0
 libX11.so.6
 libXcursor.so.1
 libXrandr.so.2'
-PKG_BIN64_DEPENDENCIES_LIBRARIES_LINUX="$PKG_BIN_DEPENDENCIES_LIBRARIES_LINUX"
-PKG_BIN32_DEPENDENCIES_LIBRARIES_LINUX="$PKG_BIN_DEPENDENCIES_LIBRARIES_LINUX"
 ## Ensure easy upgrades from packages generated with pre-20250104.1 game scripts
 PKG_BIN_PROVIDES="${PKG_BIN_PROVIDES:-}
 renowned-explorers"
-PKG_BIN64_PROVIDES="$PKG_BIN_PROVIDES"
-PKG_BIN32_PROVIDES="$PKG_BIN_PROVIDES"
 
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_ID_LINUX="${PKG_DATA_ID}-linux"
