@@ -5,11 +5,12 @@ set -o errexit
 
 ###
 # Star Wars: Galactic Battlegrounds
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241021.1
+script_version=20250310.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.31'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='star-wars-galactic-battlegrounds'
 GAME_NAME='Star Wars: Galactic Battlegrounds'
@@ -72,6 +73,11 @@ USER_PERSISTENT_FILES='
 data/*.dat
 player.nf*'
 
+## Work around CD check
+WINE_REGISTRY_INIT='
+[HKEY_LOCAL_MACHINE\Software\LucasArts Entertainment Company LLC\Star Wars Galactic Battlegrounds\1.0]
+
+"CDPath"="C:"'
 ## Without a WINE virtual desktop, only a black screen is rendered.
 WINE_VIRTUAL_DESKTOP='auto'
 
@@ -102,19 +108,6 @@ PKG_L10N_DESCRIPTION_FR='French localization'
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
 
-# Work around CD check
-
-registry_dump_nocd_file='registry-dumps/no-cd-check.reg'
-registry_dump_nocd_content='Windows Registry Editor Version 5.00
-
-[HKEY_LOCAL_MACHINE\Software\LucasArts Entertainment Company LLC\Star Wars Galactic Battlegrounds\1.0]
-"CDPath"="C:"'
-CONTENT_GAME_BIN_FILES="${CONTENT_GAME_BIN_FILES:-}
-$registry_dump_nocd_file"
-APP_REGEDIT="${APP_REGEDIT:-} $registry_dump_nocd_file"
-REQUIREMENTS_LIST="${REQUIREMENTS_LIST:-}
-iconv"
-
 # Load common functions
 
 PLAYIT_LIB_PATHS="
@@ -148,14 +141,6 @@ initialization_default "$@"
 # Extract game data
 
 archive_extraction_default
-(
-	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
-
-	## Work around CD check.
-	mkdir --parents "$(dirname "$registry_dump_nocd_file")"
-	printf '%s' "$registry_dump_nocd_content" | \
-		iconv --from-code=UTF-8 --to-code=UTF-16 --output="$registry_dump_nocd_file"
-)
 
 # Include game data
 
