@@ -10,10 +10,11 @@ set -o errexit
 # - Distant Stars
 # - Ancient Relics
 # - First Contact
+# - Grand Archive
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250917.1
+script_version=20251019.1
 
 PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
@@ -35,6 +36,9 @@ EXPANSION_NAME_ANCIENTRELICS='Ancient Relics Story Pack'
 EXPANSION_ID_FIRSTCONTACT='first-contact'
 EXPANSION_NAME_FIRSTCONTACT='First Contact Story Pack'
 
+EXPANSION_ID_FIRSTCONTACT='grand-archive'
+EXPANSION_NAME_FIRSTCONTACT='Grand Archive Story Pack'
+
 # Archives
 
 ## Leviathans
@@ -412,6 +416,14 @@ ARCHIVE_BASE_FIRSTCONTACT_2_MD5='dd862bf0d12f5bf0a7a7c116a57f2bbb'
 ARCHIVE_BASE_FIRSTCONTACT_2_SIZE='1200'
 ARCHIVE_BASE_FIRSTCONTACT_2_VERSION='3.8.4.1-gog65337'
 
+## Grand Archive
+
+ARCHIVE_BASE_ARCHIVE_0_NAME='stellaris_grand_archive_4_1_3_85354.sh'
+ARCHIVE_BASE_ARCHIVE_0_MD5='72882f69a388d7fbf66e384878004514'
+ARCHIVE_BASE_ARCHIVE_0_SIZE='33060'
+ARCHIVE_BASE_ARCHIVE_0_VERSION='4.1.3-gog85354'
+ARCHIVE_BASE_ARCHIVE_0_URL='https://www.gog.com/game/stellaris_grand_archive'
+
 
 CONTENT_PATH_DEFAULT='data/noarch/game'
 CONTENT_GAME_MAIN_FILES='
