@@ -12,13 +12,15 @@ set -o errexit
 # - Nemesis
 # - Overlord
 # - Galactic Paragons
+# - Astral Planes
 # - The Machine Age
+# - Cosmic Storms
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250504.1
+script_version=20250917.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.32'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='stellaris'
 GAME_NAME='Stellaris'
@@ -44,23 +46,29 @@ EXPANSION_NAME_OVERLORD='Overlord'
 EXPANSION_ID_PARAGONS='galactic-paragons'
 EXPANSION_NAME_PARAGONS='Galactic Paragons'
 
+EXPANSION_ID_PLANES='astral-planes'
+EXPANSION_NAME_PLANES='Astral Planes'
+
 EXPANSION_ID_MACHINE='the-machine-age'
 EXPANSION_NAME_MACHINE='The Machine Age'
 
+EXPANSION_ID_STORMS='cosmic-storms'
+EXPANSION_NAME_STORMS='Cosmic Storms'
+
 # Archives
 
 ## Utopia
 
+ARCHIVE_BASE_UTOPIA_60_NAME='stellaris_utopia_4_0_23_84679.sh'
+ARCHIVE_BASE_UTOPIA_60_MD5='36ca08b712639088b27300ef5d6348e0'
+ARCHIVE_BASE_UTOPIA_60_SIZE='75007'
+ARCHIVE_BASE_UTOPIA_60_VERSION='4.0.23-gog84679'
+ARCHIVE_BASE_UTOPIA_60_URL='https://www.gog.com/game/stellaris_utopia'
+
 ARCHIVE_BASE_UTOPIA_59_NAME='stellaris_utopia_3_14_1592653_81105.sh'
 ARCHIVE_BASE_UTOPIA_59_MD5='ce44b8d0f9afa3e05927c914d1033341'
 ARCHIVE_BASE_UTOPIA_59_SIZE='75007'
 ARCHIVE_BASE_UTOPIA_59_VERSION='3.14.1592653-gog81105'
-ARCHIVE_BASE_UTOPIA_59_URL='https://www.gog.com/game/stellaris_utopia'
-
-ARCHIVE_BASE_UTOPIA_58_NAME='stellaris_utopia_3_14_15926_78464.sh'
-ARCHIVE_BASE_UTOPIA_58_MD5='62b9c4f468f049c1943cfcda6ff8c79e'
-ARCHIVE_BASE_UTOPIA_58_SIZE='75007'
-ARCHIVE_BASE_UTOPIA_58_VERSION='3.14.15926-gog78464'
 
 ARCHIVE_BASE_UTOPIA_57_NAME='stellaris_utopia_3_13_2_0_76713.sh'
 ARCHIVE_BASE_UTOPIA_57_MD5='12459f9b139ca756b2c19a5755e41b67'
@@ -134,16 +142,16 @@ ARCHIVE_BASE_UTOPIA_17_VERSION='3.0.3-gog47193'
 
 ## Apocalypse
 
+ARCHIVE_BASE_APOCALYPSE_50_NAME='stellaris_apocalypse_4_0_23_84679.sh'
+ARCHIVE_BASE_APOCALYPSE_50_MD5='657e28499f3f9c7e7e46446b1f45bab0'
+ARCHIVE_BASE_APOCALYPSE_50_SIZE='37877'
+ARCHIVE_BASE_APOCALYPSE_50_VERSION='4.0.23-gog84679'
+ARCHIVE_BASE_APOCALYPSE_50_URL='https://www.gog.com/game/stellaris_apocalypse'
+
 ARCHIVE_BASE_APOCALYPSE_49_NAME='stellaris_apocalypse_3_14_1592653_81105.sh'
 ARCHIVE_BASE_APOCALYPSE_49_MD5='7f21a52edafc0c8a80e97a947dc5afa6'
 ARCHIVE_BASE_APOCALYPSE_49_SIZE='37877'
 ARCHIVE_BASE_APOCALYPSE_49_VERSION='3.14.1592653-gog81105'
-ARCHIVE_BASE_APOCALYPSE_49_URL='https://www.gog.com/game/stellaris_apocalypse'
-
-ARCHIVE_BASE_APOCALYPSE_48_NAME='stellaris_apocalypse_3_14_15926_78464.sh'
-ARCHIVE_BASE_APOCALYPSE_48_MD5='fe095847b18e9279daca3f2eb407cc2b'
-ARCHIVE_BASE_APOCALYPSE_48_SIZE='37877'
-ARCHIVE_BASE_APOCALYPSE_48_VERSION='3.14.15926-gog78464'
 
 ARCHIVE_BASE_APOCALYPSE_47_NAME='stellaris_apocalypse_3_13_2_0_76713.sh'
 ARCHIVE_BASE_APOCALYPSE_47_MD5='ee89fa59d427166031964f106053fd39'
@@ -217,16 +225,16 @@ ARCHIVE_BASE_APOCALYPSE_7_VERSION='3.0.3-gog47193'
 
 ## MegaCorp
 
+ARCHIVE_BASE_MEGACORP_47_NAME='stellaris_megacorp_4_0_23_84679.sh'
+ARCHIVE_BASE_MEGACORP_47_MD5='8e6ad615e3fa7a902e05f54c4e54564e'
+ARCHIVE_BASE_MEGACORP_47_SIZE='90404'
+ARCHIVE_BASE_MEGACORP_47_VERSION='4.0.23-gog84679'
+ARCHIVE_BASE_MEGACORP_47_URL='https://www.gog.com/game/stellaris_megacorp'
+
 ARCHIVE_BASE_MEGACORP_46_NAME='stellaris_megacorp_3_14_1592653_81105.sh'
 ARCHIVE_BASE_MEGACORP_46_MD5='897bda9d1e5eda534a4913245e3af69b'
 ARCHIVE_BASE_MEGACORP_46_SIZE='90404'
 ARCHIVE_BASE_MEGACORP_46_VERSION='3.14.1592653-gog81105'
-ARCHIVE_BASE_MEGACORP_46_URL='https://www.gog.com/game/stellaris_megacorp'
-
-ARCHIVE_BASE_MEGACORP_45_NAME='stellaris_megacorp_3_14_15926_78464.sh'
-ARCHIVE_BASE_MEGACORP_45_MD5='a16aec518e86ad716206899230871099'
-ARCHIVE_BASE_MEGACORP_45_SIZE='90404'
-ARCHIVE_BASE_MEGACORP_45_VERSION='3.14.15926-gog78464'
 
 ARCHIVE_BASE_MEGACORP_44_NAME='stellaris_megacorp_3_13_2_0_76713.sh'
 ARCHIVE_BASE_MEGACORP_44_MD5='e6b76bb98c26ec597e3a37b3aa915f46'
@@ -300,16 +308,16 @@ ARCHIVE_BASE_MEGACORP_4_VERSION='3.0.3-gog47193'
 
 ## Federations
 
+ARCHIVE_BASE_FEDERATIONS_42_NAME='stellaris_federations_4_0_23_84679.sh'
+ARCHIVE_BASE_FEDERATIONS_42_MD5='432adf7d8b2491d1810d1fc7182f7806'
+ARCHIVE_BASE_FEDERATIONS_42_SIZE='14433'
+ARCHIVE_BASE_FEDERATIONS_42_VERSION='4.0.23-gog84679'
+ARCHIVE_BASE_FEDERATIONS_42_URL='https://www.gog.com/game/stellaris_federations'
+
 ARCHIVE_BASE_FEDERATIONS_41_NAME='stellaris_federations_3_14_1592653_81105.sh'
 ARCHIVE_BASE_FEDERATIONS_41_MD5='ce2828f957f35b1ce114c1bf66fa65c2'
 ARCHIVE_BASE_FEDERATIONS_41_SIZE='14433'
 ARCHIVE_BASE_FEDERATIONS_41_VERSION='3.14.1592653-gog81105'
-ARCHIVE_BASE_FEDERATIONS_41_URL='https://www.gog.com/game/stellaris_federations'
-
-ARCHIVE_BASE_FEDERATIONS_40_NAME='stellaris_federations_3_14_15926_78464.sh'
-ARCHIVE_BASE_FEDERATIONS_40_MD5='11fb43cc5b19aebd6bbece34c75492c5'
-ARCHIVE_BASE_FEDERATIONS_40_SIZE='14433'
-ARCHIVE_BASE_FEDERATIONS_40_VERSION='3.14.15926-gog78464'
 
 ARCHIVE_BASE_FEDERATIONS_39_NAME='stellaris_federations_3_13_2_0_76713.sh'
 ARCHIVE_BASE_FEDERATIONS_39_MD5='48ff77ab8c028f6088a0c6743da2bbed'
@@ -373,16 +381,16 @@ ARCHIVE_BASE_FEDERATIONS_1_VERSION='3.2.2-gog51685'
 
 ## Nemesis
 
+ARCHIVE_BASE_NEMESIS_29_NAME='stellaris_nemesis_4_0_23_84679.sh'
+ARCHIVE_BASE_NEMESIS_29_MD5='dad4d0666016994358fcacb23c64e018'
+ARCHIVE_BASE_NEMESIS_29_SIZE='38539'
+ARCHIVE_BASE_NEMESIS_29_VERSION='4.0.23-gog84679'
+ARCHIVE_BASE_NEMESIS_29_URL='https://www.gog.com/game/stellaris_nemesis'
+
 ARCHIVE_BASE_NEMESIS_28_NAME='stellaris_nemesis_3_14_1592653_81105.sh'
 ARCHIVE_BASE_NEMESIS_28_MD5='7d686008bc3b604c55578cb7b72b711b'
 ARCHIVE_BASE_NEMESIS_28_SIZE='38539'
 ARCHIVE_BASE_NEMESIS_28_VERSION='3.14.1592653-gog81105'
-ARCHIVE_BASE_NEMESIS_28_URL='https://www.gog.com/game/stellaris_nemesis'
-
-ARCHIVE_BASE_NEMESIS_27_NAME='stellaris_nemesis_3_14_15926_78464.sh'
-ARCHIVE_BASE_NEMESIS_27_MD5='d950bf759ba6311143b1be3ec6811fd7'
-ARCHIVE_BASE_NEMESIS_27_SIZE='38539'
-ARCHIVE_BASE_NEMESIS_27_VERSION='3.14.15926-gog78464'
 
 ARCHIVE_BASE_NEMESIS_26_NAME='stellaris_nemesis_3_13_2_0_76713.sh'
 ARCHIVE_BASE_NEMESIS_26_MD5='3ab5141b829c7747c4622b92789fbe43'
@@ -426,11 +434,16 @@ ARCHIVE_BASE_NEMESIS_0_VERSION='3.6.1-gog60754'
 
 ## Overlord
 
+ARCHIVE_BASE_OVERLORD_24_NAME='stellaris_overlord_4_0_23_84679.sh'
+ARCHIVE_BASE_OVERLORD_24_MD5='9a854138d0831c661965036719252902'
+ARCHIVE_BASE_OVERLORD_24_SIZE='99860'
+ARCHIVE_BASE_OVERLORD_24_VERSION='4.0.23-gog84679'
+ARCHIVE_BASE_OVERLORD_24_URL='https://www.gog.com/game/stellaris_overlord'
+
 ARCHIVE_BASE_OVERLORD_23_NAME='stellaris_overlord_3_14_1592653_81105.sh'
 ARCHIVE_BASE_OVERLORD_23_MD5='b556024c88c3d9dec03c8e5945de49b4'
 ARCHIVE_BASE_OVERLORD_23_SIZE='99860'
 ARCHIVE_BASE_OVERLORD_23_VERSION='3.14.1592653-gog81105'
-ARCHIVE_BASE_OVERLORD_23_URL='https://www.gog.com/game/stellaris_overlord'
 
 ARCHIVE_BASE_OVERLORD_22_NAME='stellaris_overlord_3_14_15926_78464.sh'
 ARCHIVE_BASE_OVERLORD_22_MD5='cbc6247838f41c5d8f78c6fb6dba8ac4'
@@ -469,16 +482,16 @@ ARCHIVE_BASE_OVERLORD_2_VERSION='3.8.4.1-gog65337'
 
 ## Galactic Paragons
 
+ARCHIVE_BASE_PARAGONS_24_NAME='stellaris_galactic_paragons_4_0_23_84679.sh'
+ARCHIVE_BASE_PARAGONS_24_MD5='c32dc8e5ece651f47c1e585b4ea98e5c'
+ARCHIVE_BASE_PARAGONS_24_SIZE='832'
+ARCHIVE_BASE_PARAGONS_24_VERSION='4.0.23-gog84679'
+ARCHIVE_BASE_PARAGONS_24_URL='https://www.gog.com/game/stellaris_galactic_paragons'
+
 ARCHIVE_BASE_PARAGONS_23_NAME='stellaris_galactic_paragons_3_14_1592653_81105.sh'
 ARCHIVE_BASE_PARAGONS_23_MD5='b3a00f45cec93aea1ff6a2a0108935a5'
 ARCHIVE_BASE_PARAGONS_23_SIZE='832'
 ARCHIVE_BASE_PARAGONS_23_VERSION='3.14.1592653-gog81105'
-ARCHIVE_BASE_PARAGONS_23_URL='https://www.gog.com/game/stellaris_galactic_paragons'
-
-ARCHIVE_BASE_PARAGONS_22_NAME='stellaris_galactic_paragons_3_14_15926_78464.sh'
-ARCHIVE_BASE_PARAGONS_22_MD5='fd01b388fa76e46e8739a70d26c682f0'
-ARCHIVE_BASE_PARAGONS_22_SIZE='832'
-ARCHIVE_BASE_PARAGONS_22_VERSION='3.14.15926-gog78464'
 
 ARCHIVE_BASE_PARAGONS_21_NAME='stellaris_galactic_paragons_3_13_2_0_76713.sh'
 ARCHIVE_BASE_PARAGONS_21_MD5='ce85a2dffe8e2f5dc5fd691622d96518'
@@ -510,18 +523,51 @@ ARCHIVE_BASE_PARAGONS_2_MD5='e47a7ab7c264021f49b8419e1aedc580'
 ARCHIVE_BASE_PARAGONS_2_SIZE='1200'
 ARCHIVE_BASE_PARAGONS_2_VERSION='3.8.4.1-gog65337'
 
+## Astral Planes
+
+ARCHIVE_BASE_PLANES_18_NAME='stellaris_astral_planes_4_0_23_84679.sh'
+ARCHIVE_BASE_PLANES_18_MD5='e34bcde8db82137627e7bccaca471be5'
+ARCHIVE_BASE_PLANES_18_SIZE='46789'
+ARCHIVE_BASE_PLANES_18_VERSION='4.0.23-gog84679'
+ARCHIVE_BASE_PLANES_18_URL='https://www.gog.com/game/stellaris_astral_planes'
+
+ARCHIVE_BASE_PLANES_17_NAME='stellaris_astral_planes_3_14_1592653_81105.sh'
+ARCHIVE_BASE_PLANES_17_MD5='27e12dbda8a5734ec6bd94e6eda650d9'
+ARCHIVE_BASE_PLANES_17_SIZE='46789'
+ARCHIVE_BASE_PLANES_17_VERSION='3.14.1592653-gog81105'
+
+ARCHIVE_BASE_PLANES_15_NAME='stellaris_astral_planes_3_13_2_0_76713.sh'
+ARCHIVE_BASE_PLANES_15_MD5='8350550427b8df4980d5b10b680f8068'
+ARCHIVE_BASE_PLANES_15_SIZE='46789'
+ARCHIVE_BASE_PLANES_15_VERSION='3.13.2-gog76713'
+
+ARCHIVE_BASE_PLANES_12_NAME='stellaris_astral_planes_3_12_5_74193.sh'
+ARCHIVE_BASE_PLANES_12_MD5='8cbaaaa68306cc90effacd2510cbe089'
+ARCHIVE_BASE_PLANES_12_SIZE='46789'
+ARCHIVE_BASE_PLANES_12_VERSION='3.12.5-gog74193'
+
+ARCHIVE_BASE_PLANES_8_NAME='stellaris_astral_planes_3_11_3_0_72561.sh'
+ARCHIVE_BASE_PLANES_8_MD5='7d43cac5e6dd18238fff6f06b82be7c1'
+ARCHIVE_BASE_PLANES_8_SIZE='46789'
+ARCHIVE_BASE_PLANES_8_VERSION='3.11.3-gog72561'
+
+ARCHIVE_BASE_PLANES_5_NAME='stellaris_astral_planes_3_10_4_70670.sh'
+ARCHIVE_BASE_PLANES_5_MD5='fab105e52dffbf0ec425d4cedf89feae'
+ARCHIVE_BASE_PLANES_5_SIZE='46789'
+ARCHIVE_BASE_PLANES_5_VERSION='3.10.4-gog70670'
+
 ## The Machine Age
 
+ARCHIVE_BASE_MACHINE_9_NAME='stellaris_the_machine_age_4_0_23_84679.sh'
+ARCHIVE_BASE_MACHINE_9_MD5='bd0a016b3974fa441665e2dcf89bb700'
+ARCHIVE_BASE_MACHINE_9_SIZE='100390'
+ARCHIVE_BASE_MACHINE_9_VERSION='4.0.23-gog84679'
+ARCHIVE_BASE_MACHINE_9_URL='https://www.gog.com/game/stellaris_the_machine_age'
+
 ARCHIVE_BASE_MACHINE_8_NAME='stellaris_the_machine_age_3_14_1592653_81105.sh'
 ARCHIVE_BASE_MACHINE_8_MD5='07b714aa18a9c9ff40f5fbf03cf59e2d'
 ARCHIVE_BASE_MACHINE_8_SIZE='100390'
 ARCHIVE_BASE_MACHINE_8_VERSION='3.14.1592653-gog81105'
-ARCHIVE_BASE_MACHINE_8_URL='https://www.gog.com/game/stellaris_the_machine_age'
-
-ARCHIVE_BASE_MACHINE_7_NAME='stellaris_the_machine_age_3_14_15926_78464.sh'
-ARCHIVE_BASE_MACHINE_7_MD5='ab74106e42a9b5525ae852ca27b7020f'
-ARCHIVE_BASE_MACHINE_7_SIZE='100390'
-ARCHIVE_BASE_MACHINE_7_VERSION='3.14.15926-gog78464'
 
 ARCHIVE_BASE_MACHINE_6_NAME='stellaris_the_machine_age_3_13_2_0_76713.sh'
 ARCHIVE_BASE_MACHINE_6_MD5='113ee29d7d37fc5de99f1716114a12f3'
@@ -533,6 +579,24 @@ ARCHIVE_BASE_MACHINE_3_MD5='06614dbbb8a94b20449f6a3a6f863347'
 ARCHIVE_BASE_MACHINE_3_SIZE='118726'
 ARCHIVE_BASE_MACHINE_3_VERSION='3.12.5-gog74193'
 
+## Cosmic Storms
+
+ARCHIVE_BASE_STORMS_5_NAME='stellaris_cosmic_storms_4_0_23_84679.sh'
+ARCHIVE_BASE_STORMS_5_MD5='b34dac8b2fb7970f171a5ec9a07232e1'
+ARCHIVE_BASE_STORMS_5_SIZE='829'
+ARCHIVE_BASE_STORMS_5_VERSION='4.0.23-gog84679'
+ARCHIVE_BASE_STORMS_5_URL='https://www.gog.com/game/stellaris_cosmic_storms'
+
+ARCHIVE_BASE_STORMS_4_NAME='stellaris_cosmic_storms_3_14_1592653_81105.sh'
+ARCHIVE_BASE_STORMS_4_MD5='672c8bb0d4992b1e76f827fe351fb69a'
+ARCHIVE_BASE_STORMS_4_SIZE='829'
+ARCHIVE_BASE_STORMS_4_VERSION='3.14.1592653-gog81105'
+
+ARCHIVE_BASE_STORMS_2_NAME='stellaris_cosmic_storms_3_13_2_0_76713.sh'
+ARCHIVE_BASE_STORMS_2_MD5='a011e1ef5f111c624be7cbbcd5a924fa'
+ARCHIVE_BASE_STORMS_2_SIZE='829'
+ARCHIVE_BASE_STORMS_2_VERSION='3.13.2-gog76713'
+
 
 CONTENT_PATH_DEFAULT='data/noarch/game'
 CONTENT_GAME_MAIN_FILES='
@@ -543,7 +607,7 @@ PKG_PARENT_ID="$GAME_ID"
 PKG_MAIN_DEPENDENCIES_SIBLINGS='
 PKG_PARENT'
 
-# Load common functions
+# Load common functions.
 
 PLAYIT_LIB_PATHS="
 $PWD
@@ -569,24 +633,24 @@ fi
 # shellcheck source=libplayit2.sh
 . "$PLAYIT_LIB2"
 
-# Run the default initialization actions
+# Run default initialisation actions.
 
 initialization_default "$@"
 
-# Extract game data
+# Extract game data.
 
 archive_extraction_default
 
-# Include game data
+# Include game data.
 
 content_inclusion_default
 
-# Build packages
+# Build packages.
 
 packages_generation
 print_instructions
 
-# Clean up
+# Clean up.
 
 working_directory_cleanup
 
