@@ -1,7 +1,7 @@
 #!/bin/sh
 # SPDX-License-Identifier: BSD-2-Clause
 # SPDX-FileCopyrightText: © 2015 Antoine Le Gonidec <vv221@dotslashplay.it>
-# SPDX-FileCopyrightText: © 2019 BetaRays
+# SPDX-FileCopyrightText: © 2019 BetaRays <array@dotslashplay.it>
 set -o errexit
 
 ###
@@ -9,16 +9,28 @@ set -o errexit
 # send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250802.1
+script_version=20250920.1
 
 PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='the-witcher-1'
 GAME_NAME='The Witcher'
 
-## FIXME: This archive and the previous one could be merged,
-##        if ARCHIVE_xxx_MD5 had support for multiple values.
+## FIXME: This archive and the previous ones could be merged, if ARCHIVE_xxx_MD5 had support for multiple values.
 ##        (./play.it 2.33.0)
+ARCHIVE_BASE_3_NAME='setup_the_witcher_enhanced_edition_directors_cut_1.5_(cs)_gog_0.2_(77554).exe'
+ARCHIVE_BASE_3_MD5='5b6f7dd2247e5fbb1d0049dcc5de6b63'
+ARCHIVE_BASE_3_TYPE='innosetup'
+ARCHIVE_BASE_3_PART1_NAME='setup_the_witcher_enhanced_edition_directors_cut_1.5_(cs)_gog_0.2_(77554)-1.bin'
+ARCHIVE_BASE_3_PART1_MD5='8d242faffa4b3b8dc09ff8697401ece3'
+ARCHIVE_BASE_3_PART2_NAME='setup_the_witcher_enhanced_edition_directors_cut_1.5_(cs)_gog_0.2_(77554)-2.bin'
+ARCHIVE_BASE_3_PART2_MD5='869b510afebbd14e208a5252392662c7'
+ARCHIVE_BASE_3_PART3_NAME='setup_the_witcher_enhanced_edition_directors_cut_1.5_(cs)_gog_0.2_(77554)-3.bin'
+ARCHIVE_BASE_3_PART3_MD5='d9fc78540f616d0deb1fe83a91032138'
+ARCHIVE_BASE_3_SIZE='14782478'
+ARCHIVE_BASE_3_VERSION='1.5.726-gog77554'
+ARCHIVE_BASE_3_URL='https://www.gog.com/game/the_witcher'
+
 ARCHIVE_BASE_2_NAME='setup_the_witcher_enhanced_edition_directors_cut_1.5_(cs)_gog_0.2_(77554).exe'
 ARCHIVE_BASE_2_MD5='97cffb60d12f41bf03c84165a79a9157'
 ARCHIVE_BASE_2_TYPE='innosetup'
@@ -30,7 +42,6 @@ ARCHIVE_BASE_2_PART3_NAME='setup_the_witcher_enhanced_edition_directors_cut_1.5_
 ARCHIVE_BASE_2_PART3_MD5='b5fd3359b7129903a13baf731496f0c7'
 ARCHIVE_BASE_2_SIZE='14785291'
 ARCHIVE_BASE_2_VERSION='1.5.726-gog77554'
-ARCHIVE_BASE_2_URL='https://www.gog.com/game/the_witcher'
 
 ARCHIVE_BASE_1_NAME='setup_the_witcher_enhanced_edition_directors_cut_1.5_(cs)_gog_0.2_(77554).exe'
 ARCHIVE_BASE_1_MD5='3d8467c76abe8cd16711ada268e1600f'
