@@ -6,11 +6,12 @@ set -o errexit
 
 ###
 # Victor Vran
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241229.1
+script_version=20250318.1
 
-PLAYIT_COMPATIBILITY_LEVEL='2.32'
+PLAYIT_COMPATIBILITY_LEVEL='2.33'
 
 GAME_ID='victor-vran'
 GAME_NAME='Victor Vran'
@@ -65,14 +66,9 @@ libXt.so.6'
 PKG_DATA_ID="${GAME_ID}-data"
 PKG_DATA_DESCRIPTION='data'
 
-PRELOAD_HACKS_LIST='
-HACK_NOATIME'
+# Work around the engine expectation that files are owned by the current user
 
-## LD_PRELOAD shim working around the engine expectation that files are owned by the current user
-HACK_NOATIME_NAME='vv_noatime'
-HACK_NOATIME_DESCRIPTION='LD_PRELOAD shim working around the engine expectation that files are owned by the current user'
-HACK_NOATIME_PACKAGE='PKG_BIN'
-HACK_NOATIME_SOURCE='
+LD_PRELOAD_SOURCE='
 #define _GNU_SOURCE
 #include <dlfcn.h>
 #include <sys/types.h>
@@ -133,10 +129,6 @@ fi
 
 initialization_default "$@"
 
-# Build and include the LD_PRELOAD shims
-
-hacks_inclusion_default
-
 # Include shipped libgcrypt.so.11 on Debian
 # Use the system-provided libraries on Arch Linux and Gentoo
 
