@@ -5,15 +5,39 @@ set -o errexit
 
 ###
 # Warhammer 40k: Rogue Trader
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20250212.1
+script_version=20250306.1
 
 PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
 GAME_ID='warhammer-40k-rogue-trader'
 GAME_NAME='Warhammer 40,000: Rogue Trader'
 
+ARCHIVE_BASE_6_NAME='setup_warhammer_40000_rogue_trader_windows_1.3.2.13_release_(80103).exe'
+ARCHIVE_BASE_6_MD5='45d3f481b2fb210a843334a712554958'
+ARCHIVE_BASE_6_TYPE='innosetup'
+ARCHIVE_BASE_6_PART1_NAME='setup_warhammer_40000_rogue_trader_windows_1.3.2.13_release_(80103)-1.bin'
+ARCHIVE_BASE_6_PART1_MD5='eda89a11f948f200f4c56237285fb9b9'
+ARCHIVE_BASE_6_PART2_NAME='setup_warhammer_40000_rogue_trader_windows_1.3.2.13_release_(80103)-2.bin'
+ARCHIVE_BASE_6_PART2_MD5='8949a2fc4b96b54c2307e4764843b772'
+ARCHIVE_BASE_6_PART3_NAME='setup_warhammer_40000_rogue_trader_windows_1.3.2.13_release_(80103)-3.bin'
+ARCHIVE_BASE_6_PART3_MD5='a91cfd8b31c9b6d70e925dd0a9be15ef'
+ARCHIVE_BASE_6_PART4_NAME='setup_warhammer_40000_rogue_trader_windows_1.3.2.13_release_(80103)-4.bin'
+ARCHIVE_BASE_6_PART4_MD5='2bc3bd62513a295c5b7273458cff6f6d'
+ARCHIVE_BASE_6_PART5_NAME='setup_warhammer_40000_rogue_trader_windows_1.3.2.13_release_(80103)-5.bin'
+ARCHIVE_BASE_6_PART5_MD5='4f7a9191151f5c901ebca190e181faa9'
+ARCHIVE_BASE_6_PART6_NAME='setup_warhammer_40000_rogue_trader_windows_1.3.2.13_release_(80103)-6.bin'
+ARCHIVE_BASE_6_PART6_MD5='a26289180a5296bb2f0f3eea4cb3f615'
+ARCHIVE_BASE_6_PART7_NAME='setup_warhammer_40000_rogue_trader_windows_1.3.2.13_release_(80103)-7.bin'
+ARCHIVE_BASE_6_PART7_MD5='1a48f99811600d78a2dfe86956bdf5e8'
+ARCHIVE_BASE_6_PART8_NAME='setup_warhammer_40000_rogue_trader_windows_1.3.2.13_release_(80103)-8.bin'
+ARCHIVE_BASE_6_PART8_MD5='246389293503a141c111471c3a4ba35f'
+ARCHIVE_BASE_6_SIZE='37045414'
+ARCHIVE_BASE_6_VERSION='1.3.2.13-gog80103'
+ARCHIVE_BASE_6_URL='https://www.gog.com/game/warhammer_40000_rogue_trader'
+
 ARCHIVE_BASE_5_NAME='setup_warhammer_40000_rogue_trader_windows_1.3.1.11_release_(79404).exe'
 ARCHIVE_BASE_5_MD5='71407e5f100c9afb88d8a876acbe51b7'
 ARCHIVE_BASE_5_TYPE='innosetup'
@@ -35,7 +59,6 @@ ARCHIVE_BASE_5_PART8_NAME='setup_warhammer_40000_rogue_trader_windows_1.3.1.11_r
 ARCHIVE_BASE_5_PART8_MD5='f7bb783d1b27594b3628838afe9db6d2'
 ARCHIVE_BASE_5_SIZE='37048733'
 ARCHIVE_BASE_5_VERSION='1.3.1.11-gog79404'
-ARCHIVE_BASE_5_URL='https://www.gog.com/game/warhammer_40000_rogue_trader'
 
 ARCHIVE_BASE_4_NAME='setup_warhammer_40000_rogue_trader_windows_1.3.1.6_release_(78738).exe'
 ARCHIVE_BASE_4_MD5='13a67e2d41eaa13be8b5b029f5689960'
