@@ -8,9 +8,10 @@ set -o errexit
 
 ###
 # Worms: Armageddon
+# send your bug reports to vv221@dotslashplay.it
 ###
 
-script_version=20241230.1
+script_version=20250603.1
 
 PLAYIT_COMPATIBILITY_LEVEL='2.32'
 
@@ -53,9 +54,6 @@ lflmb10n.dll
 lftga10n.dll
 wa.exe
 user/bankeditor.exe'
-## TODO: Check if the Steam library is required
-CONTENT_GAME0_BIN_FILES='
-steam_api.dll'
 CONTENT_GAME_DATA_FILES='
 data
 fesfx
